import Button from "../Helpers/Button.ts";
import type HasActionModalData from "../Interfaces/HasActionModalData.ts";
/**
 * Modal class.
 *
 * @since 1.0.0
 */
export default class Modal {
    private modalData;
    /**
     * Show modal.
     *
     * @param modalData Modal data.
     *
     * @since 1.0.0
     */
    constructor(modalData: HasActionModalData);
    /**
     * Is modal visible.
     *
     * @returns True if modal is visible, false otherwise.
     *
     * @since 1.0.0
     */
    isVisible(): boolean;
    /**
     * Modal title.
     *
     * @returns Modal title.
     *
     * @since 1.0.0
     */
    getTitle(): string | undefined;
    /**
     * Modal body.
     *
     * @returns Modal body.
     *
     * @since 1.0.0
     */
    getBody(): string | undefined;
    /**
     * Get buttons.
     *
     * @returns Modal buttons.
     *
     * @since 1.0.0
     */
    getButtons(): Button[] | undefined;
    /**
     * Hide modal.
     *
     * @since 1.0.0
     */
    dismiss(): void;
    /**
     * Check if modal exists.
     *
     * @since 1.0.0
     */
    exists(): boolean;
}
