import type HasFieldsetData from '../Interfaces/HasFieldsetData.ts';
import type Content from '../Fields/Content.ts';
import CSSClasses from '../Helpers/CSSClasses.ts';
import Conditions from '../Helpers/Conditions.ts';
import MultipleField from '../Fields/MultipleField.ts';
import SingleField from '../Fields/SingleField.ts';
/**
 * Class Fieldset.
 *
 * @since 1.0.0
 */
export default class Fieldset {
    readonly id: string;
    readonly legend: string;
    readonly icon: string;
    readonly fields: (Content | SingleField | MultipleField)[];
    readonly nextFieldset: string;
    readonly prevFieldset: string;
    readonly conditions: Conditions;
    readonly classes: CSSClasses;
    readonly legendClasses: CSSClasses;
    readonly fieldsClasses: CSSClasses;
    /**
     * Constructor.
     *
     * @param form Form object.
     *
     * @since 1.0.0
     */
    constructor(fieldsetData: HasFieldsetData, formValues?: []);
    /**
     * Has next fieldset.
     *
     * @returns True if has next fieldset, false otherwise.
     *
     * @since 1.0.0
     */
    hasNext(): boolean;
    /**
     * Has previous fieldset.
     *
     * @returns True if has previous fieldset, false otherwise.
     *
     * @since 1.0.0
     */
    hasPrev(): boolean;
    /**
     * Has previous fieldset.
     *
     * @returns True if has previous fieldset, false otherwise.
     *
     * @since 1.0.0
     */
    isComplete(): boolean;
}
